==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/acpcfg.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'cfg_explain_auth_activate_limit'=>'Wie lange dürfen neue Benutzerkonten unaktiviert bleiben bevor sie entfernt werden?',
'cfg_explain_auth_bind_agent'=>'Bei der Anmeldung wird die aktuelle Browserkennung gespeichert. Die Zugriffserlaubnis wird ungültig, wenn die Bindung <u>aktiviert</u> ist und die Kennung sich ändert.',
'cfg_explain_auth_bind_ip'=>'Bei der Anmeldung wird die aktuelle IP-Adresse gespeichert. Die Zugriffserlaubnis wird ungültig, wenn die Bindung <u>aktiviert</u> ist und die Adresse sich ändert.',
'cfg_explain_auth_max_faillogin'=>'Wie viele Fehlanmeldungen sind möglich bevor die Möglichkeit der Anmeldung für einige Minuten unterbunden wird?',
'cfg_explain_auth_max_lifetime'=>'Wie lange bleibt eine Zugriffserlaubnis nach einer Anmeldung gültig?',
'cfg_explain_auth_use_reauth'=>'Darf eine ungültige Zugriffserlaubnis ein paar mal durch erneute Kennworteingabe erneuert werden?',
'cfg_explain_auth_use_tan'=>'Sollen Änderungen durch Formulare ausgelöst mit einer Transakionsnummer (TAN) gesichert werden?',
'cfg_explain_cache_acl'=>'Zwischenspeichern der Zugriffsregeln aktivieren?',
'cfg_explain_cache_config'=>'Zwischenspeichern der Einstellungen aktivieren?',
'cfg_explain_cache_main'=>'Zwischenspeichern von allgemeinen Daten aktivieren?',
'cfg_explain_cache_rss'=>'Zwischenspeichern der erzeugten RSS-Feeds aktivieren?',
'cfg_explain_cache_topic'=>'Zwischenspeichern der Themendaten aktivieren?',
'cfg_explain_cache_tpl'=>'Zwischenspeichern der erzeugten HTML-Vorlagen (Templates) aktivieren?',
'cfg_explain_cache_user'=>'Zwischenspeichern der Benutzerdaten aktivieren?',
'cfg_explain_cookie_domain'=>'Du kannst hier die Gültigkeit der Cookies auf bestimmte Domäne begrenzen. Üblicherweise steht hier dein vollständiger Domänenname ("www.beispiel.de").',
'cfg_explain_cookie_path'=>'Hier lassen sich die Cookies auf einen bestimmten Pfad innerhalb der Domäne einschränken. Am einfachsten ist "/".',
'cfg_explain_cookie_read_tracker'=>'Der Name des "Zuletzt-Gelesener-Beitrag-Zeitstempel"-Cookie.',
'cfg_explain_cookie_session'=>'Name des Zugriffserlaubnis-Cookies.',
'cfg_explain_cookie_ssl_only'=>'Sofern <u>aktiviert</u>, werden Cookies ausschließlich über eine gesicherte (SSL) Verbindung gesendet.',
'cfg_explain_help_class'=>'Welche Art der Unterstützung möchtest du deinen Benutzern anbieten? <u>direct</u> erfordert das Schreiben von Beiträgen im Forum und <u>mail</u> nutzt stattdessen E-Mail.',
'cfg_explain_help_mail_address'=>'Falls du "mail" als Möglichkeit gewählt hast, trage hier bitte die E-Mail Adresse ein.',
'cfg_explain_http_detect_language'=>'Du kannst hier die Spracherkennung für deine Besucher aktivieren. Oft senden ihre Browser die bevorzugten Sprachen mit.',
'cfg_explain_http_output_zlib'=>'Möchtest du das die Ausgabe des Forums komprimiert übertragen werden? Das erhöht leicht die Last auf dem Server und wird deaktiviert, falls der Besucher sie nicht unterstützt.',
'cfg_explain_log_enable'=>'Protokollierung nutzen? Die Nachrichten werden mindestens in die Datenbank geschrieben.',
'cfg_explain_log_forward'=>'Wo möchtest du die Protokollmeldungen sonst noch ablegen? Du kannst sie an eine andere Logeinrichtung weiterleiten, um deine Protokolle zu archivieren. Bitte beachte, daß zusätzliche Parameter nötig sein können - siehe "log_parameter".',
'cfg_explain_log_ip'=>'Soll die IP-Adresse ebenfalls gespeichert werden? Falls <u>deaktiviert</u>, wird eine Dummy-Adresse genutzt.',
'cfg_explain_log_max_age'=>'Wie lange sollen Protokolleinträge in der Datenbank aufbewahrt werden? Eine geplante Aufgabe wird sich dann darum kümmern. Wähle den Wert <u>0</u> für unendliche Zeit. Dies betrifft keine Weiterleitungen, die per "log_engine" durchgeführt werden!',
'cfg_explain_log_parameter'=>'Wenn "log_engine" gleich "filexxx" ist, dann wird ein voller Pfad zur Archivdatei erwartet. "syslog" hat keine. <u>Deaktivieren</u> kannst die Weiterleitung über "none".',
'cfg_explain_log_statistic'=>'Sollen einige Statistiken über das Forum geführt werden? Diese kannst du später im "Protokoll" nachvollziehen. Das ganze ist unabhängig von sonstigen Protokoll - du kannst die Statistiken sammeln auch wenn das allgemeine Protokoll deaktivert ist.',
'cfg_explain_mail_from_mail'=>'Welche E-Mail Adresse soll in vom Forum versendete Mails stehen?',
'cfg_explain_mail_from_name'=>'Welcher Name soll in vom Forum versendete Mails stehen?',
'cfg_explain_main_debug_verbose'=>'Solange dieses Feld <u>aktiviert</u> ist, kannst du ausführlichere Informationen bei Fehlerberichten einsehen. ',
'cfg_explain_main_default_group'=>'Ein frisch registrierter Benutzer wird dieser Benutzergruppe zugewiesen.',
'cfg_explain_main_enable'=>'Läuft das Forum? <u>Deaktivere</u> es im Wartungsfall, sodaß keine Änderungen stattfinden.',
'cfg_explain_main_guest_uid'=>'Welches ist die Benutzer-ID des Gastzuganges?',
'cfg_explain_main_language'=>'Wähle die standardmäßig eingestellte Sprache, falls eine benutzerdefinierte nicht vorhanden ist.',
'cfg_explain_main_post_edit_limit'=>'Wie lange dürfen Benutzer ohne Verwalterreche ihre Beiträge ändern?',
'cfg_explain_main_post_per_page'=>'Gib die Anzahl der Beiträge an, die in einem Thema pro Seite angezeigt werden.',
'cfg_explain_main_style'=>'Welches Aussehen soll üblicherweise angezeigt werden?',
'cfg_explain_main_tags_on_index'=>'Wie viele der "häufigen Stichwörter" soll auf der Startseite angezeigt werden?',
'cfg_explain_main_title'=>'Die Titelzeile deines Forums.',
'cfg_explain_main_topic_navbar'=>'Falls du dies <u>aktivierst</u>, wird eine zusätzliche Navigationsleiste in der Themenansicht angezeigt. Sie enthält Verknüpfungen zum nächsten, letzten und verwandten Beiträgen. Dies kann die Last auf die Datenbank stark erhöhen. Bitte mit Vorsicht benutzen!',
'cfg_explain_main_topic_per_page'=>'Wie viele Themen sollen auf der Hauptseite angezeigt werden?',
'cfg_explain_param_action'=>'Name des GET-Parameter für "Action".',
'cfg_explain_param_ajax'=>'Dateiname des "Asynchrone Anfragen" (AJAX) Proxy.',
'cfg_explain_param_file'=>'Dateiname der Hauptdatei.',
'cfg_explain_root_path'=>'Der Wurzelpfad deines Forums. Muß eine absolute Angabe im Dateisystem ohne abschließenden Schrägstrich sein.',
'cfg_explain_root_uri'=>'Die Wurzel-URI deines Forums. Muß eine gülige URI ohne abschließenden Schrägstrich sein. Falls eine gesicherte Verbindung über "https" aufgebaut wird, paßt das Forum diese entsprechend an.',
'cfg_explain_rss_limit'=>'Die maximale Anzahl an Beiträgen, die in einem RSS-Feed zu finden sind.',
'cfg_explain_rss_payload'=>'Sollen die Beitragstexte im RSS-Feed angezeigt werden?',
'cfg_explain_task_enable'=>'Geplante Aufgaben aktivieren?',
'cfg_explain_uri_css'=>'Die volle URI zu den Stylesheets ohne abschließenden Schrägstrich.',
'cfg_explain_uri_gfx'=>'Die volle URI zu den Bildern ohne abschließenden Schrägstrich.',
'cfg_explain_uri_js'=>'Die volle URI zu den Javascripts ohne abschließenden Schrägstrich.',
'config_aux_auth'=>'Diese Einstellungen kontrollieren die Autentifizierung von angemeldeten Benutzern. Um die Zugriffserlaubnis zu straffen, kannst du sie an die vom Benutzer mitgeteilten Daten "binden". In seltenen Fällen führt dies zu einer raschen Abmeldung. Jedoch können die Benutzer die Prüfung dann in ihren Profilen abschalten.',
'config_aux_cache'=>'Wir empfehlen alle Zwischenspeicher zu aktivieren, um die Leistung zu erhöhen und die Serverlast zu senken. Allerdings kann dann manchmal alter Inhalt zu sehen sein. In dem Fall kannst du die "Zwischenspeicher-Verwaltung" nutzen, um ein Neu einlesen zu erzwingen.',
'config_aux_cookie'=>'Für Benutzer ist nötig ihre Zugriffserlaubnis über ein Cookie zu senden. Das ist eine kleine Textdatei, die ihr Browser speichert. Alle Cookies sind verschlüsselt und falls du SSL-Verbindungen nutzt, solltest du sie auf "Nur-SSL" einstellen.',
'config_aux_help'=>'Diese Einstellungen beeinflussen die Übersicht, wenn die Benutzer in der Navigationsleiste auf "Hilfe" klicken.',
'config_aux_http'=>'Jegliche explizite HTTP-Optionen können hier gesetzt werden.',
'config_aux_log'=>'Es ist ratsam das Protokollieren von Aktionen im Forum zu nutzen. Sobald deine Datenschutz-Bestimmungen es erfordern, kannst du das speichern von IP-Adressen abschalten.',
'config_aux_mail'=>'Absenderinformationen bei versendeten E-Mails im Fall einer Registrierung oder Passwort-Anfragen.',
'config_aux_main'=>'Hier befinden sich die Haupteinstellungen des Forums. Sie kontrollieren alles, was nicht in die anderen Kategorien paßt.',
'config_aux_param'=>'Die meisten Benutzer können diese Einstellungen belassen. Nur erfahrene sollten sie ändern.',
'config_aux_root'=>'Beide Pfade geben dein Forum-Wurzelverzeichnis an. Einmal aus HTTP-Sicht und einmal von Dateisystem aus. Sie sind üblicherweise während der Installation erkannt worden und bedürfen keiner Anpassung.',
'config_aux_rss'=>'Jeder Besucher kann die Themen über den RSS-Feed abonnieren. Diese können in einen Newsaggregator eingespeist und angeschaut werden ohne das Forum besuchen zu müssen.',
'config_aux_task'=>'Eine Geplante Aufgabe wird regelmäßig alle paar Minuten ausgeführt und übernimmt Wartungsaufgaben im Hintergrund.',
'config_aux_uri'=>'Du kannst hier die Pfade zu allen Ressourcen, welche vom Forum benutzt werden, festlegen. Die meisten Benutzer können dies so belassen.',
'config_aux__'=>'Alle Forumeinstellungen auf einen Blick. Weitere Informationen sind verfügbar, wenn du auf einen Bereich eingrenzt.',
'config_seg_all'=>'Alle Einstellungen',
'config_seg_auth'=>'Autentifizierung-Einstellungen',
'config_seg_cache'=>'Zwischenspeicher-Einstellungen',
'config_seg_cookie'=>'Cookie-Einstellungen',
'config_seg_help'=>'Hilfe-Einstellungen',
'config_seg_http'=>'HTTP-Einstellungen',
'config_seg_log'=>'Protokoll-Einstellungen',
'config_seg_mail'=>'Mail-Einstellungen',
'config_seg_main'=>'Haupt-Einstellungen',
'config_seg_param'=>'Parameter: Haupt',
'config_seg_root'=>'Parameter: Wurzel',
'config_seg_rss'=>'RSS-Einstellungen',
'config_seg_task'=>'Geplante Aufgaben-Einstellungen',
'config_seg_uri'=>'Parameter: URI'
);
?>

==> larus_board-0.9.18.zip: larus_board-0.9.18/lb_private/lang/de/acpcfg.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'cfg_explain_auth_activate_limit'=>'Wie lange dürfen neue Benutzerkonten unaktiviert bleiben bevor sie entfernt werden?',
'cfg_explain_auth_bind_agent'=>'Bei der Anmeldung wird die aktuelle Browserkennung gespeichert. Die Zugriffserlaubnis wird ungültig, wenn die Bindung <u>aktiviert</u> ist und die Kennung sich ändert.',
'cfg_explain_auth_bind_ip'=>'Bei der Anmeldung wird die aktuelle IP-Adresse gespeichert. Die Zugriffserlaubnis wird ungültig, wenn die Bindung <u>aktiviert</u> ist und die Adresse sich ändert.',
'cfg_explain_auth_max_faillogin'=>'Wie viele Fehlanmeldungen sind möglich bevor die Möglichkeit der Anmeldung für einige Minuten unterbunden wird?',
'cfg_explain_auth_max_lifetime'=>'Wie lange bleibt eine Zugriffserlaubnis nach einer Anmeldung gültig?',
'cfg_explain_auth_use_reauth'=>'Darf eine ungültige Zugriffserlaubnis ein paar mal durch erneute Kennworteingabe erneuert werden?',
'cfg_explain_auth_use_tan'=>'Sollen Änderungen durch Formulare ausgelöst mit einer Transakionsnummer (TAN) gesichert werden?',
'cfg_explain_cache_acl'=>'Zwischenspeichern der Zugriffsregeln aktivieren?',
'cfg_explain_cache_config'=>'Zwischenspeichern der Einstellungen aktivieren?',
'cfg_explain_cache_main'=>'Zwischenspeichern von allgemeinen Daten aktivieren?',
'cfg_explain_cache_rss'=>'Zwischenspeichern der erzeugten RSS-Feeds aktivieren?',
'cfg_explain_cache_topic'=>'Zwischenspeichern der Themendaten aktivieren?',
'cfg_explain_cache_tpl'=>'Zwischenspeichern der erzeugten HTML-Vorlagen (Templates) aktivieren?',
'cfg_explain_cache_user'=>'Zwischenspeichern der Benutzerdaten aktivieren?',
'cfg_explain_cookie_domain'=>'Du kannst hier die Gültigkeit der Cookies auf eine bestimmte Domäne begrenzen. Üblicherweise steht hier dein vollständiger Domänenname ("www.beispiel.de").',
'cfg_explain_cookie_path'=>'Hier lassen sich die Cookies auf einen bestimmten Pfad innerhalb der Domäne einschränken. Am einfachsten ist "/".',
'cfg_explain_cookie_read_tracker'=>'Der Name des "Zuletzt-Gelesener-Beitrag-Zeitstempel"-Cookie.',
'cfg_explain_cookie_session'=>'Name des Zugriffserlaubnis-Cookies.',
'cfg_explain_cookie_ssl_only'=>'Sofern <u>aktiviert</u>, werden Cookies ausschließlich über eine gesicherte (SSL) Verbindung gesendet.',
'cfg_explain_help_class'=>'Welche Art der Unterstützung möchtest du deinen Benutzern anbieten? <u>direct</u> erfordert das Schreiben von Beiträgen im Forum und <u>mail</u> nutzt stattdessen E-Mail.',
'cfg_explain_help_mail_address'=>'Falls du "mail" als Möglichkeit gewählt hast, trage hier bitte die E-Mail Adresse ein.',
'cfg_explain_http_detect_language'=>'Du kannst hier die Spracherkennung für deine Besucher aktivieren. Oft senden ihre Browser die bevorzugten Sprachen mit.',
'cfg_explain_http_output_zlib'=>'Möchtest du das die Ausgabe des Forums komprimiert übertragen werden? Das erhöht leicht die Last auf dem Server und wird deaktiviert, falls der Besucher sie nicht unterstützt.',
'cfg_explain_log_enable'=>'Protokollierung nutzen? Die Nachrichten werden mindestens in die Datenbank geschrieben.',
'cfg_explain_log_forward'=>'Wo möchtest du die Protokollmeldungen sonst noch ablegen? Du kannst sie an eine andere Logeinrichtung weiterleiten, um deine Protokolle zu archivieren. Bitte beachte, daß zusätzliche Parameter nötig sein können - siehe "log_parameter".',
'cfg_explain_log_ip'=>'Soll die IP-Adresse ebenfalls gespeichert werden? Falls <u>deaktiviert</u>, wird eine Dummy-Adresse genutzt.',
'cfg_explain_log_max_age'=>'Wie lange sollen Protokolleinträge in der Datenbank aufbewahrt werden? Eine geplante Aufgabe wird sich dann darum kümmern. Wähle den Wert <u>0</u> für unendliche Zeit. Dies betrifft keine Weiterleitungen, die per "log_engine" durchgeführt werden!',
'cfg_explain_log_parameter'=>'Wenn "log_forward" gleich "filexxx" ist, dann wird ein voller Pfad zur Archivdatei erwartet. "syslog" hat keine. <u>Deaktivieren</u> kannst die Weiterleitung über "none".',
'cfg_explain_log_statistic'=>'Sollen einige Statistiken über das Forum geführt werden? Diese kannst du später im "Protokoll" nachvollziehen. Das ganze ist unabhängig von sonstigen Protokoll - du kannst die Statistiken sammeln auch wenn das allgemeine Protokoll deaktivert ist.',
'cfg_explain_mail_from_mail'=>'Welche E-Mail Adresse soll in vom Forum versendeten Mails stehen?',
'cfg_explain_mail_from_name'=>'Welcher Name soll in vom Forum versendeten Mails stehen?',
'cfg_explain_main_debug_verbose'=>'Solange dieses Feld <u>aktiviert</u> ist, kannst du ausführlichere Informationen bei Fehlerberichten einsehen ("Exception Handler"). Bitte sei damit vorsichtig, da es jeder sehen kann, der einen Fehler erhält.',
'cfg_explain_main_default_group'=>'Ein frisch registrierter Benutzer wird dieser Benutzergruppe zugewiesen.',
'cfg_explain_main_enable'=>'Läuft das Forum? <u>Deaktivere</u> es im Wartungsfall, sodaß keine Änderungen stattfinden.',
'cfg_explain_main_guest_uid'=>'Welches ist die Benutzer-ID des Gastzuganges?',
'cfg_explain_main_language'=>'Wähle die standardmäßig eingestellte Sprache, falls eine benutzerdefinierte nicht vorhanden ist.',
'cfg_explain_main_post_edit_limit'=>'Wie lange dürfen Benutzer ohne Verwalterreche ihre Beiträge ändern?',
'cfg_explain_main_post_per_page'=>'Gib die Anzahl der Beiträge an, die in einem Thema pro Seite angezeigt werden.',
'cfg_explain_main_style'=>'Welches Aussehen soll üblicherweise angezeigt werden?',
'cfg_explain_main_tags_on_index'=>'Wie viele der "häufigen Stichwörter" soll auf der Startseite angezeigt werden?',
'cfg_explain_main_title'=>'Die Titelzeile deines Forums.',
'cfg_explain_main_topic_navbar'=>'Falls du dies <u>aktivierst</u>, wird eine zusätzliche Navigationsleiste in der Themenansicht angezeigt. Sie enthält Verknüpfungen zum nächsten, letzten und verwandten Beiträgen. Dies kann die Last auf die Datenbank stark erhöhen. Bitte mit Vorsicht benutzen!',
'cfg_explain_main_topic_per_page'=>'Wie viele Themen sollen auf der Hauptseite angezeigt werden?',
'cfg_explain_param_action'=>'Name des GET-Parameter für "Action".',
'cfg_explain_param_ajax'=>'Dateiname des "Asynchrone Anfragen" (AJAX) Proxy.',
'cfg_explain_param_file'=>'Dateiname der Hauptdatei.',
'cfg_explain_root_path'=>'Der Wurzelpfad deines Forums. Muß eine absolute Angabe im Dateisystem ohne abschließenden Schrägstrich sein.',
'cfg_explain_root_uri'=>'Die Wurzel-URI deines Forums. Muß eine gülige URI ohne abschließenden Schrägstrich sein. Falls eine gesicherte Verbindung über "https" aufgebaut wird, paßt das Forum diese entsprechend an.',
'cfg_explain_rss_limit'=>'Die maximale Anzahl an Beiträgen, die im "neueste Themen des Forums" RSS-Feed zu finden sind.',
'cfg_explain_rss_payload'=>'Sollen die Beitragstexte im RSS-Feed angezeigt werden?',
'cfg_explain_task_enable'=>'Geplante Aufgaben aktivieren?',
'cfg_explain_uri_css'=>'Die volle URI zu den Stylesheets ohne abschließenden Schrägstrich.',
'cfg_explain_uri_gfx'=>'Die volle URI zu den Bildern ohne abschließenden Schrägstrich.',
'cfg_explain_uri_js'=>'Die volle URI zu den Javascripts ohne abschließenden Schrägstrich.',
'config_aux_auth'=>'Diese Einstellungen kontrollieren die Autentifizierung von angemeldeten Benutzern. Um die Zugriffserlaubnis zu straffen, kannst du sie an die vom Benutzer mitgeteilten Daten "binden". In seltenen Fällen führt dies zu einer raschen Abmeldung. Jedoch können die Benutzer die Prüfung dann in ihren Profilen abschalten.',
'config_aux_cache'=>'Wir empfehlen alle Zwischenspeicher zu aktivieren, um die Leistung zu erhöhen und die Serverlast zu senken. Allerdings kann dann manchmal alter Inhalt zu sehen sein. In dem Fall kannst du die "Zwischenspeicher-Verwaltung" nutzen, um ein Neu einlesen zu erzwingen.',
'config_aux_cookie'=>'Für Benutzer ist nötig ihre Zugriffserlaubnis über ein Cookie zu senden. Das ist eine kleine Textdatei, die ihr Browser speichert. Alle Cookies sind verschlüsselt und falls du SSL-Verbindungen nutzt, solltest du sie auf "Nur-SSL" einstellen.',
'config_aux_help'=>'Diese Einstellungen beeinflussen die Übersicht, wenn die Benutzer in der Navigationsleiste auf "Hilfe" klicken.',
'config_aux_http'=>'Jegliche explizite HTTP-Optionen können hier gesetzt werden.',
'config_aux_log'=>'Es ist ratsam das Protokollieren von Aktionen im Forum zu nutzen. Sobald deine Datenschutz-Bestimmungen es erfordern, kannst du das Speichern von IP-Adressen abschalten.',
'config_aux_mail'=>'Absenderinformationen bei versendeten E-Mails im Fall einer Registrierung oder Passwort-Anfragen.',
'config_aux_main'=>'Hier befinden sich die Haupteinstellungen des Forums. Sie kontrollieren alles, was nicht in die anderen Kategorien paßt.',
'config_aux_param'=>'Die meisten Benutzer können diese Einstellungen belassen. Nur erfahrene sollten sie ändern.',
'config_aux_root'=>'Beide Pfade geben dein Forum-Wurzelverzeichnis an. Einmal aus HTTP-Sicht und einmal von Dateisystem aus. Sie sind üblicherweise während der Installation erkannt worden und bedürfen keiner Anpassung.',
'config_aux_rss'=>'Jeder Besucher kann die Themen über den RSS-Feed abonnieren. Diese können in einen Newsaggregator eingespeist und angeschaut werden ohne das Forum besuchen zu müssen.',
'config_aux_task'=>'Eine Geplante Aufgabe wird regelmäßig alle paar Minuten ausgeführt und übernimmt Wartungsaufgaben im Hintergrund.',
'config_aux_uri'=>'Du kannst hier die Pfade zu allen Ressourcen, welche vom Forum benutzt werden, festlegen. Die meisten Benutzer können dies so belassen.',
'config_aux__'=>'Alle Forumeinstellungen auf einen Blick. Weitere Informationen sind verfügbar, wenn du auf einen Bereich eingrenzt.',
'config_seg_all'=>'Alle Einstellungen',
'config_seg_auth'=>'Autentifizierung-Einstellungen',
'config_seg_cache'=>'Zwischenspeicher-Einstellungen',
'config_seg_cookie'=>'Cookie-Einstellungen',
'config_seg_help'=>'Hilfe-Einstellungen',
'config_seg_http'=>'HTTP-Einstellungen',
'config_seg_log'=>'Protokoll-Einstellungen',
'config_seg_mail'=>'Mail-Einstellungen',
'config_seg_main'=>'Haupt-Einstellungen',
'config_seg_param'=>'Parameter: Haupt',
'config_seg_root'=>'Parameter: Wurzel',
'config_seg_rss'=>'RSS-Einstellungen',
'config_seg_task'=>'Geplante Aufgaben-Einstellungen',
'config_seg_uri'=>'Parameter: URI'
);
?>
